@@ -1,35 +1,24 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2021 WhiteMech
+# Copyright 2021-2022 WhiteMech
 #
 # ------------------------------
 #
 # This file is part of pddl.
 #
-# pddl is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# pddl is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with pddl.  If not, see <https://www.gnu.org/licenses/>.
+# Use of this source code is governed by an MIT-style
+# license that can be found in the LICENSE file or at
+# https://opensource.org/licenses/MIT.
 #
 
 """Main entrypoint for the PDDL parser CLI tool."""
 import os
 import sys
-from pathlib import Path
 
 import click
 
+from pddl import parse_domain, parse_problem
 from pddl.formatter import domain_to_string, problem_to_string
-from pddl.parser.domain import DomainParser
-from pddl.parser.problem import ProblemParser
 
 
 @click.group()
@@ -47,7 +36,7 @@ def domain(domain_file, quiet):
     """Check a PDDL domain file is correct."""
     if quiet:
         sys.stdout = open(os.devnull, "a")
-    print(domain_to_string(DomainParser()(Path(domain_file).read_text())))
+    print(domain_to_string(parse_domain(domain_file)))
 
 
 @cli.command()
@@ -57,7 +46,7 @@ def problem(problem_file, quiet):
     """Check a PDDL problem file is correct."""
     if quiet:
         sys.stdout = open(os.devnull, "a")
-    print(problem_to_string(ProblemParser()(Path(problem_file).read_text())))
+    print(problem_to_string(parse_problem(problem_file)))
 
 
 if __name__ == "__main__":
